diff --git a/core/tests/coretests/src/android/graphics/PathTest.java b/core/tests/coretests/src/android/graphics/PathTest.java
index c6d6d1ff90d5f0a81b6c31cd2f10af4e2f125929..b50792ca6b38cefe2801a7ab2c9ef20ab74fa348 100644
--- a/core/tests/coretests/src/android/graphics/PathTest.java
+++ b/core/tests/coretests/src/android/graphics/PathTest.java
@@ -28,7 +28,9 @@ public class PathTest extends TestCase {
 
         final Path.FillType defaultFillType = path.getFillType();
         final Path.FillType fillType = Path.FillType.INVERSE_EVEN_ODD;
-        assertFalse(fillType.equals(defaultFillType));  // Sanity check for the test itself.
+
+        // This test is only meaningful if it changes from the default.
+        assertFalse(fillType.equals(defaultFillType));
 
         path.setFillType(fillType);
         path.reset();
diff --git a/libs/hwui/hwui/Bitmap.cpp b/libs/hwui/hwui/Bitmap.cpp
index c21bdca3db77fe06afcb69c3298cba33fc543675..7352061bd2cdee37a71c115840ae5ef1613a7134 100644
--- a/libs/hwui/hwui/Bitmap.cpp
+++ b/libs/hwui/hwui/Bitmap.cpp
@@ -182,11 +182,8 @@ static SkImageInfo validateAlpha(const SkImageInfo& info) {
 void Bitmap::reconfigure(const SkImageInfo& newInfo, size_t rowBytes) {
     mInfo = validateAlpha(newInfo);
 
-    // Dirty hack is dirty
-    // TODO: Figure something out here, Skia's current design makes this
-    // really hard to work with. Skia really, really wants immutable objects,
-    // but with the nested-ref-count hackery going on that's just not
-    // feasible without going insane trying to figure it out
+    // TODO: Skia intends for SkPixelRef to be immutable, but this method
+    // modifies it. Find another way to support reusing the same pixel memory.
     this->android_only_reset(mInfo.width(), mInfo.height(), rowBytes);
 }
diff --git a/graphics/java/android/graphics/Region.java b/graphics/java/android/graphics/Region.java
index d8d96413a93d90be3c6e7acbf8e65ca5a7cbb667..43373ffbd3f45a33e07caeebc32427c9a71c4956 100644
--- a/graphics/java/android/graphics/Region.java
+++ b/graphics/java/android/graphics/Region.java
@@ -409,10 +409,10 @@ public class Region implements Parcelable {
         mNativeRegion = ni;
     }
 
     /* add dummy parameter so constructor can be called from jni without
        triggering 'not cloneable' exception */
     @UnsupportedAppUsage
-    private Region(long ni, int dummy) {
+    private Region(long ni, int unused) {
         this(ni);
     }
 
@@ -409,10 +409,10 @@ public class Region implements Parcelable {
     }
 
-    /* add dummy parameter so constructor can be called from jni without
+    /* Add an unused parameter so constructor can be called from jni without
        triggering 'not cloneable' exception */
     @UnsupportedAppUsage